@@ -1,3 +1,6 @@
+"""
+Defines the public API for FlowKit
+"""
 from ._models.sample import Sample
 # noinspection PyProtectedMember
 from ._models.transforms._matrix import Matrix
@@ -9,9 +12,10 @@ from ._models.dimension import Dimension, RatioDimension, QuadrantDivider
 from ._models.vertex import Vertex
 from ._utils.xml_utils import parse_gating_xml, export_gatingml
 from ._utils.wsp_utils import parse_wsp
-from ._utils.plot_utils import plot_channel, calculate_extent
 from ._utils.sample_utils import load_samples, calculate_compensation_from_beads
 
+from ._version import __version__
+
 __all__ = [
     'Sample',
     'Session',
@@ -26,8 +30,6 @@ __all__ = [
     'parse_gating_xml',
     'export_gatingml',
     'parse_wsp',
-    'plot_channel',
-    'calculate_extent',
     'load_samples',
     'calculate_compensation_from_beads'
 ]
